@@ -359,15 +359,11 @@ void mk_plugin_api_init(struct mk_server *server)
     api->time_to_gmt = mk_utils_utime2gmt;
     api->time_human  = mk_plugin_time_now_human;
 
-#ifdef TRACE
+#ifdef MK_HAVE_TRACE
     api->trace = mk_utils_trace;
     api->errno_print = mk_utils_print_errno;
 #endif
 
-#ifdef JEMALLOC_STATS
-    api->je_mallctl = je_mallctl;
-#endif
-
     api->stacktrace = (void *) mk_utils_stacktrace;
     api->kernel_version = mk_kernel_version;
     api->kernel_features_print = mk_kernel_features_print;
