@@ -796,6 +796,7 @@ int flb_input_collector_running(int coll_id, struct flb_input_instance *in)
     return coll->running;
 }
 
+
 int flb_input_pause_all(struct flb_config *config)
 {
     int paused = 0;
@@ -878,6 +879,11 @@ int flb_input_collector_resume(int coll_id, struct flb_input_instance *in)
     config = in->config;
     event = &coll->event;
 
+    /* If data ingestion has been paused, the collector cannot resume */
+    if (config->is_ingestion_active == FLB_FALSE) {
+        return 0;
+    }
+
     if (coll->type == FLB_COLLECT_TIME) {
         event->mask = MK_EVENT_EMPTY;
         event->status = MK_EVENT_NONE;
@@ -937,7 +943,7 @@ int flb_input_set_collector_socket(struct flb_input_instance *in,
     mk_list_add(&collector->_head, &config->collectors);
     mk_list_add(&collector->_head_ins, &in->collectors);
 
-    return 0;
+    return collector->id;
 }
 
 int flb_input_collector_fd(flb_pipefd_t fd, struct flb_config *config)
