@@ -2,7 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019      The Fluent Bit Authors
+ *  Copyright (C) 2019-2020 The Fluent Bit Authors
  *  Copyright (C) 2015-2018 Treasure Data Inc.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
@@ -52,6 +52,21 @@ int flb_slist_add_n(struct mk_list *head, const char *str, int len)
     return 0;
 }
 
+int flb_slist_add_sds(struct mk_list *head, flb_sds_t str)
+{
+    struct flb_slist_entry *e;
+
+    e = flb_malloc(sizeof(struct flb_slist_entry));
+    if (!e) {
+        flb_errno();
+        return -1;
+    }
+
+    e->str = str;
+    mk_list_add(&e->_head, head);
+    return 0;
+}
+
 /* Append NULL terminated string as a new node into the list */
 int flb_slist_add(struct mk_list *head, const char *str)
 {
@@ -69,6 +84,130 @@ int flb_slist_add(struct mk_list *head, const char *str)
     return flb_slist_add_n(head, str, len);
 }
 
+static inline int token_unescape(char *token)
+{
+    char *in = token;
+    char *out = token;
+
+    while (*in) {
+        if ((in[0] == '\\') && (in[1] == '"')) {
+            *out = in[1];
+            out++;
+            in += 2;
+        }
+        else {
+            *out = *in;
+            out++;
+            in++;
+        }
+    }
+    *out = 0;
+    return out - token;
+}
+
+static flb_sds_t token_retrieve(char **str)
+{
+    int len;
+    int quoted = FLB_FALSE;
+    char *p;
+    char *start;
+    char *prev;
+    flb_sds_t out = NULL;
+
+    if (!*str) {
+        return NULL;
+    }
+
+    p = *str;
+
+    /* Skip empty spaces */
+    while (*p == ' ') {
+        p++;
+    }
+    start = p;
+
+    if (*p == '"') {
+        quoted = FLB_TRUE;
+        p++;
+        start = p;
+        while (1) {
+            while (*p && *p != '"') {
+                p++;
+            }
+
+            if (!*p) {
+                goto exit;
+            }
+
+            prev = p - 1;
+            if (*prev == '\\') {
+                p++;
+                continue;
+            }
+            goto exit;
+        }
+    }
+
+    while (*p && *p != ' ') {
+        p++;
+    }
+
+ exit:
+    if (*p) {
+        out = flb_sds_create_len(start, p - start);
+        if (quoted == FLB_TRUE) {
+            len = token_unescape(out);
+            flb_sds_len_set(out, len);
+        }
+        p++;
+
+        while (*p && *p == ' ') {
+            p++;
+        }
+        *str = p;
+    }
+    else {
+        if (p > start) {
+            out = flb_sds_create(start);
+        }
+        *str = NULL;
+    }
+
+    return out;
+}
+
+int flb_slist_split_tokens(struct mk_list *list, const char *str, int max_split)
+{
+    int count = 0;
+    char *p;
+    char *buf;
+    flb_sds_t tmp = NULL;
+
+    buf = (char *) str;
+    while ((tmp = token_retrieve(&buf))) {
+        flb_slist_add_sds(list, tmp);
+        if (!buf) {
+            break;
+        }
+        count++;
+
+        /* Append remaining string if we use a maximum number of tokens */
+        if (count >= max_split && max_split > 0) {
+            p = buf;
+            while (*p == ' ') {
+                p++;
+            }
+
+            if (*p) {
+                flb_slist_add(list, p);
+            }
+            break;
+        }
+    }
+
+    return 0;
+}
+
 /*
  * Split a string using a separator, every splitted content is appended to the end of
  * the slist list head.
