@@ -66,7 +66,6 @@ static inline void map_free_task_id(int id, struct flb_config *config)
     config->tasks_map[id].task = NULL;
 }
 
-
 void flb_task_retry_destroy(struct flb_task_retry *retry)
 {
     int ret;
@@ -93,7 +92,7 @@ int flb_task_retry_reschedule(struct flb_task_retry *retry, struct flb_config *c
     struct flb_task *task;
 
     task = retry->parent;
-    seconds = flb_sched_request_create(config, retry, retry->attemps);
+    seconds = flb_sched_request_create(config, retry, retry->attempts);
     if (seconds == -1) {
         /*
          * This is the worse case scenario: 'cannot re-schedule a retry'. If the Chunk
@@ -129,9 +128,9 @@ struct flb_task_retry *flb_task_retry_create(struct flb_task *task,
     mk_list_foreach_safe(head, tmp, &task->retries) {
         retry = mk_list_entry(head, struct flb_task_retry, _head);
         if (retry->o_ins == o_ins) {
-            if (retry->attemps >= o_ins->retry_limit && o_ins->retry_limit >= 0) {
-                flb_debug("[task] task_id=%i reached retry-attemps limit %i/%i",
-                          task->id, retry->attemps, o_ins->retry_limit);
+            if (retry->attempts >= o_ins->retry_limit && o_ins->retry_limit >= 0) {
+                flb_debug("[task] task_id=%i reached retry-attempts limit %i/%i",
+                          task->id, retry->attempts, o_ins->retry_limit);
                 flb_task_retry_destroy(retry);
                 return NULL;
             }
@@ -148,18 +147,18 @@ struct flb_task_retry *flb_task_retry_create(struct flb_task *task,
             return NULL;
         }
 
-        retry->attemps = 1;
+        retry->attempts = 1;
         retry->o_ins   = o_ins;
         retry->parent  = task;
         mk_list_add(&retry->_head, &task->retries);
 
-        flb_debug("[retry] new retry created for task_id=%i attemps=%i",
-                  out_th->task->id, retry->attemps);
+        flb_debug("[retry] new retry created for task_id=%i attempts=%i",
+                  out_th->task->id, retry->attempts);
     }
     else {
-        retry->attemps++;
-        flb_debug("[retry] re-using retry for task_id=%i attemps=%i",
-                  out_th->task->id, retry->attemps);
+        retry->attempts++;
+        flb_debug("[retry] re-using retry for task_id=%i attempts=%i",
+                  out_th->task->id, retry->attempts);
     }
 
     /*
@@ -200,7 +199,7 @@ int flb_task_retry_count(struct flb_task *task, void *data)
     mk_list_foreach(head, &task->retries) {
         retry = mk_list_entry(head, struct flb_task_retry, _head);
         if (retry->o_ins == o_ins) {
-            return retry->attemps;
+            return retry->attempts;
         }
     }
 
@@ -272,11 +271,18 @@ int flb_task_running_count(struct flb_config *config)
 {
     int count = 0;
     struct mk_list *head;
+    struct mk_list *t_head;
+    struct flb_task *task;
     struct flb_input_instance *ins;
 
     mk_list_foreach(head, &config->inputs) {
         ins = mk_list_entry(head, struct flb_input_instance, _head);
-        count += mk_list_size(&ins->tasks);
+        mk_list_foreach(t_head, &ins->tasks) {
+            task = mk_list_entry(t_head, struct flb_task, _head);
+            if (task->users > 0) {
+                count++;
+            }
+        }
     }
 
     return count;
@@ -345,6 +351,7 @@ struct flb_task *flb_task_create(uint64_t ref_id,
     struct flb_task *task;
     struct flb_task_route *route;
     struct flb_output_instance *o_ins;
+    struct flb_input_chunk *task_ic;
     struct mk_list *o_head;
 
     /* No error status */
@@ -369,6 +376,9 @@ struct flb_task *flb_task_create(uint64_t ref_id,
     task->tag[tag_len] = '\0';
     task->tag_len = tag_len;
 
+    task_ic = (struct flb_input_chunk *) ic;
+    task_ic->task = task;
+
     /* Keep track of origins */
     task->ref_id = ref_id;
     task->buf    = buf;
@@ -381,18 +391,12 @@ struct flb_task *flb_task_create(uint64_t ref_id,
     task->records = ((struct flb_input_chunk *) ic)->total_records;
 #endif
 
-    /* Find matching routes for the incoming tag */
+    /* Find matching routes for the incoming task */
     mk_list_foreach(o_head, &config->outputs) {
         o_ins = mk_list_entry(o_head,
                               struct flb_output_instance, _head);
-
-        if (flb_router_match(task->tag, task->tag_len, o_ins->match
-#ifdef FLB_HAVE_REGEX
-                             , o_ins->match_regex
-#else
-                             , NULL
-#endif
-                             )) {
+        
+        if ((((struct flb_input_chunk *) ic)->routes_mask & o_ins->mask_id) > 0) {
             route = flb_malloc(sizeof(struct flb_task_route));
             if (!route) {
                 flb_errno();
